-- displays data gathered by the core in FuBar

local WhoRoll, self = WhoRoll, WhoRoll

local tooltip = LibStub('LibQTip-1.0'):Acquire('WhoRollTooltip', 3)

local function HideTooltip()
	tooltip:SetScript( "OnLeave", nil )
	tooltip:Hide()
end

local ldbdata = {
	type = "launcher", 
	icon = [[Interface/Buttons/UI-GroupLoot-Dice-Up]], 
	OnClick = function(_, msg)
			if msg == "LeftButton" then
				--
			end
		end,
	label = "WhoRoll",
	OnEnter = function ( self )
		tooltip:EnableMouse()
		tooltip:SmartAnchorTo( self )
		tooltip:Show()
	end,
	OnLeave = function ( self )
		if MouseIsOver( tooltip ) then
			tooltip:SetScript( 'OnLeave', HideTooltip )
		else
			HideTooltip()
		end
	end,
}

self.obj = LibStub("LibDataBroker-1.1"):NewDataObject("WhoRoll", ldbdata)

-- globals
local _G = _G
local NEED = _G.NEED
local GREED = _G.GREED
local PASS = _G.PASS
local GetItemInfo = _G.GetItemInfo
local GetItemQualityColor = _G.GetItemQualityColor
local UnitInRaid = _G.UnitInRaid
local UnitInParty = _G.UnitInParty
local GetNumPartyMembers = _G.GetNumPartyMembers
local GetNumRaidMembers = _G.GetNumRaidMembers
local UnitName = _G.UnitName

local lootIcons = {
	[NEED] = "Interface/Buttons/UI-GroupLoot-Dice-Up",
	[GREED] = "Interface/Buttons/UI-GroupLoot-Coin-Up",
	[PASS] = "Interface/Buttons/UI-GroupLoot-Pass-Up",
}

function WhoRoll:UpdateTooltip()
	
	tooltip:Clear()
	
	local title = tooltip:AddLine()
	tooltip:SetCell(title, 1, "WhoRoll", tooltip:GetHeaderFont(), "CENTER", 3)
	local count = 0
	for k,v in pairs(self.currentLoots) do
		count = count + 1
		
		local itemName, _, quality, _, _, _, _,_,_, texture = GetItemInfo(k)
		local _,_,_,hex = GetItemQualityColor(quality)
		
		local line = tooltip:AddLine(nil, nil, hex .. itemName .. "|r")
		tooltip:SetCell(line,1,"|T" .. texture .. ":0:0:0:0|t",nil,"CENTER",2)
		
		local function getIcon(name)
			if not v.rolls[name] then
				return ""
			else
				return "  |T" .. lootIcons[v.rolls[name]] .. ":0:0:0:0|t"
			end
		end
		
		if UnitInRaid("player") then
		
			for i = 1,GetNumRaidMembers() do
				local name = UnitName("raid" .. i)
				tooltip:AddLine(nil, getIcon(name), name)
			end
			
		elseif UnitInParty("player") then

			local name = UnitName("player")
			tooltip:AddLine(nil, getIcon(name), name)
			
			for i = 1,GetNumPartyMembers() do
				name = UnitName("party" .. i)
				tooltip:AddLine(nil, getIcon(name), name)
			end
		end
		
	end
	
	if count > 0 then
		count = "|cff1eff00" .. count .. "|r"
	end
	
	self.obj.text = string.format("%s Rolls", count)
	
end
