WhoRoll = LibStub("AceAddon-3.0"):NewAddon("WhoRoll", "AceEvent-3.0")

local WhoRoll, self = WhoRoll, WhoRoll

local deformat = AceLibrary("Deformat-2.0")

self.currentLoots = {}

-- globals
local _G = _G
local GREED = _G.GREED
local NEED = _G.NEED
local PASS = _G.PASS
local LOOT_ROLL_GREED_SELF = _G.LOOT_ROLL_GREED_SELF
local LOOT_ROLL_GREED = _G.LOOT_ROLL_GREED
local LOOT_ROLL_NEED_SELF = _G.LOOT_ROLL_NEED_SELF
local LOOT_ROLL_NEED = _G.LOOT_ROLL_NEED
local LOOT_ROLL_PASSED_SELF = _G.LOOT_ROLL_PASSED_SELF
local LOOT_ROLL_PASSED_SELF_AUTO = _G.LOOT_ROLL_PASSED_SELF_AUTO
local LOOT_ROLL_PASSED = _G.LOOT_ROLL_PASSED
local LOOT_ROLL_PASSED_AUTO = _G.LOOT_ROLL_PASSED_AUTO
local LOOT_ROLL_PASSED_AUTO_FEMALE = _G.LOOT_ROLL_PASSED_AUTO_FEMALE
local LOOT_ROLL_WON = _G.LOOT_ROLL_WON
local LOOT_ROLL_ALL_PASSED = _G.LOOT_ROLL_ALL_PASSED
local GetItemInfo = _G.GetItemInfo
local GetLootRollItemLink = _G.GetLootRollItemLink
local GetLootRollItemInfo = _G.GetLootRollItemInfo

local function del(t)
	if not t or type(t) ~= "table" then
		-- return silently
		return
	end
	for k in pairs(t) do
		if type(t[k]) == "table" then
			del(t[k])
		else
			t[k] = nil
		end
	end
	t = nil
end

local function debug(msg)
	--@alpha@
	--ChatFrame4:AddMessage(msg)
	--@end-alpha@
end

function WhoRoll:OnEnable()
	
	self:RegisterEvent("START_LOOT_ROLL")
	self:RegisterEvent("CHAT_MSG_LOOT")
	self:RegisterEvent("CANCEL_LOOT_ROLL")
	
	self:UpdateTooltip()
	
end

function WhoRoll:START_LOOT_ROLL(_, rollId, rollTime)
	
	local link = GetLootRollItemLink(rollId)
	
	debug("START_LOOT_ROLL: .. " .. rollId .. "... " .. link)
	
	if not self.currentLoots[link] then
		newLootWatch = {}
		newLootWatch.rollId = rollId
		newLootWatch.name = select(2,GetLootRollItemInfo(rollId))
		newLootWatch.rolls = {}
		self.currentLoots[link] = newLootWatch
	end
	
	self:UpdateTooltip()
	
end

function WhoRoll:CHAT_MSG_LOOT(_, message)
	local itemLink, name, selection
	
	if deformat(message,LOOT_ROLL_GREED_SELF) then
		itemLink = deformat(message,LOOT_ROLL_GREED_SELF)
		name = UnitName("player")
		selection = GREED
		
	elseif deformat(message,LOOT_ROLL_GREED) then
		name, itemLink = deformat(message,LOOT_ROLL_GREED)
		selection = GREED
		
	elseif deformat(message,LOOT_ROLL_NEED_SELF) then
		itemLink = deformat(message,LOOT_ROLL_NEED_SELF)
		name = UnitName("player")
		selection = NEED
		
	elseif deformat(message,LOOT_ROLL_NEED) then
		name, itemLink = deformat(message,LOOT_ROLL_NEED)
		selection = NEED
		
	elseif deformat(message, LOOT_ROLL_PASSED_SELF_AUTO) then
		name = UnitName("player")
		itemLink = deformat(message,LOOT_ROLL_PASSED_SELF_AUTO)
		selection = PASS
		
	elseif deformat(message, LOOT_ROLL_PASSED_AUTO) then
		name, itemLink = deformat(message,LOOT_ROLL_PASSED_AUTO)
		selection = PASS
		
	elseif deformat(message, LOOT_ROLL_PASSED_AUTO_FEMALE) then
		name, itemLink = deformat(message,LOOT_ROLL_PASSED_AUTO_FEMALE)
		selection = PASS
		
	elseif deformat(message, LOOT_ROLL_PASSED_SELF) then
		name = UnitName("player")
		itemLink = deformat(message,LOOT_ROLL_PASSED_SELF)
		selection = PASS
		
	elseif deformat(message, LOOT_ROLL_PASSED) then
		name, itemLink = deformat(message,LOOT_ROLL_PASSED)
		selection = PASS
		
	elseif deformat(message,LOOT_ROLL_WON) then
		name, itemLink = deformat(message,LOOT_ROLL_WON)
		-- remove it
		del(self.currentLoots[itemLink])
		self.currentLoots[itemLink] = nil
		self:UpdateTooltip()
		return
		
	elseif deformat(message, LOOT_ROLL_ALL_PASSED) then
		itemLink = deformat(message,LOOT_ROLL_ALL_PASSED)
		-- remove it
		debug("everyone passed")
		del(self.currentLoots[itemLink])
		self.currentLoots[itemLink] = nil
		self:UpdateTooltip()
		return
		
	else
-- 		didn't match anything
		debug("string could not be matched")
		debug(message)
		return
	end
	
	-- this can happen when the player automatically passes
	if not self.currentLoots[itemLink] then
		self.currentLoots[itemLink] = {}
		self.currentLoots[itemLink].rolls = {}
	end
	
	thisLoot = self.currentLoots[itemLink]	
	thisLoot.rolls[name] = selection
	self:UpdateTooltip()
	
end

function WhoRoll:CANCEL_LOOT_ROLL(_, rollid)
	for k,v in pairs(self.currentLoots) do
		if v.rollId == rollid then
			del(v)
			return
		end
	end
end
